@@ -227,7 +227,7 @@ draw.rings <- function(name="mytree", tree.dir="trees", sep=",", normal=TRUE, da
   if(length(out) == 0)
     out <- read.table(file.path(tree.dir, name, paste0(name, "_probs.txt")), header=TRUE, sep="\t")
   if(length(cc) == 1)
-    cc <- ccurve(1, postbomb)
+    cc <- rintcal::ccurve(1, postbomb)
 
   if(length(y2.lim) > 0)
     C14.lim <- y2.lim else
@@ -310,5 +310,5 @@ draw.rings <- function(name="mytree", tree.dir="trees", sep=",", normal=TRUE, da
       segments(best.age-dat[,4], dat[,2]-dat[,3], best.age-dat[,4], dat[,2]+dat[,3], col=date.col)
       polygon(agepol, col=dist.col, border=dist.col)
       segments(rng[1], min(C14.lim), rng[2], min(C14.lim), lwd=5, col=range.col)
-    }
+    }  
 }
