@@ -49,7 +49,7 @@
 #'
 #' Christen JA, Perez S, 2009. A new robust statistical model for radiocarbon data. Radiocarbon 51, 1047-1059
 #'
-#' Kuzmin Y, Slusarenko I, Hajdas I, Bonani G, Christen JA. 2004. The comparison of 14C wiggle-matching results for the ‘floating’ tree-ring chronology of the Ulandryk-4 Burial Ground (Altai Mountains, Siberia). Radiocarbon 46, 943–948.
+#' Kuzmin Y, Slusarenko I, Hajdas I, Bonani G, Christen JA. 2004. The comparison of 14C wiggle-matching results for the 'floating' tree-ring chronology of the Ulandryk-4 Burial Ground (Altai Mountains, Siberia). Radiocarbon 46, 943–948.
 #'
 #' @export
 rings <- function(name="Ulandryk", tree.dir="trees", sep=",", normal=FALSE, delta.R=0, delta.STD=0, t.a=3, t.b=4, ask=TRUE, age.steps=1, cutoff=1e-6, prob=.95, cc=1, postbomb=FALSE, BCAD=FALSE, times=3, talk=TRUE, draw=TRUE, ...) {
@@ -88,7 +88,7 @@ rings <- function(name="Ulandryk", tree.dir="trees", sep=",", normal=FALSE, delt
   # MCMC not required or recommendable here; all calendar years in the relevant section are calculated
   if(ncol(dat) > 4)
     cc <- unique(dat[which(dat[,5] %in% 1:4),5])[1] # only use 1 entry
-  cc <- ccurve(cc, postbomb)
+  cc <- rintcal::ccurve(cc, postbomb)
   
   cc.min <- max(1, which(cc[,2] <= (max(dat[,2]+times*dat[,3]))))
   cc.max <- min(nrow(cc), which(cc[,2] >= min(dat[,2]-times*dat[,3])))
